==> dotup_flutter_simulator-3.0.0.tar.gz: lib/src/simulator/simulator_controller.dart <==
import 'package:dotup_flutter_widgets/dotup_flutter_widgets.dart';
import 'package:flutter/material.dart';

import '../device/device_changed.dart';
import '../device/device_descriptor.dart';
import '../settings/menu_position.dart';
import '../settings/simulator_settings.dart';

class SimulatorController extends ChangeNotifier {
  late final SimulatorSettings _settings;
  late MediaQueryData _realMediaQuery;
  late DeviceDescriptor _currentDecvice;
  late Orientation _currentOrientation;
  late Brightness _brightness;
  late MenuPosition _menuPosition;
  late bool _showMenuBar;

  SimulatorController(SimulatorSettings settings) {
    _settings = settings;
    _currentDecvice = settings.initialPlatform == TargetPlatform.android
        ? settings.androidDevices[settings.initialDeviceIndex]
        : settings.iosDevices[settings.initialDeviceIndex];
    _currentOrientation = settings.orientation;
    _brightness = settings.brightness;
    _menuPosition = settings.menuPosition;
    _showMenuBar = settings.showBottomBar;
  }

  SimulatorSettings get settings => _settings;

  Brightness get brightness => _brightness;

  DeviceDescriptor get currentDevice => _currentDecvice;

  Orientation get orientation => _currentOrientation;

  MediaQueryData get realMediaQuery => _realMediaQuery;

  Size get simulatedSize => _settings.androidDevices[0].size;

  Color get accentColor => Colors.red;

  Color get dividerColor => Colors.red;

  bool get showColorSelector => true;

  bool get showMenuBar => _showMenuBar;

  MenuPosition get menuPosition => _menuPosition;

  TargetPlatform get currentPlatform => _currentDecvice.platform;

  void onBrightnessChanged(Brightness value) {
    _brightness = value;
    notifyListeners();
  }

  void onColorChanged(ColorDescriptor? color) {}

  void onDeviceChanged(DeviceChanged device) {
    _currentDecvice = device.device;
    _currentOrientation = device.orientation;
    notifyListeners();
  }

  void setRealMediaQuery(MediaQueryData data) {
    _realMediaQuery = data;
  }

  void onLogoClick() {
    var next = _menuPosition.index + 1;
    if (next >= MenuPosition.values.length) {
      next = 0;
    }
    _menuPosition = MenuPosition.values[next];
    notifyListeners();
    // _realMediaQuery = data;
  }

  void toggleMenu() {
    _showMenuBar = !_showMenuBar;
    notifyListeners();
  }
}

// import 'package:dotup_flutter_widgets/dotup_flutter_widgets.dart';
// import 'package:flutter/material.dart';

// import '../device/device_changed.dart';
// import '../device/device_descriptor.dart';
// import '../settings/menu_position.dart';
// import '../settings/simulator_settings.dart';

// class SimulatorController extends ChangeNotifier {
//   late final SimulatorSettings _settings;
//   late MediaQueryData _realMediaQuery;
//   late DeviceDescriptor _currentDecvice;
//   late Orientation _currentOrientation;
//   late Brightness _brightness;
//   late MenuPosition _menuPosition;

//   SimulatorController(SimulatorSettings settings) {
//     _settings = settings;
//     _currentDecvice = settings.initialPlatform == TargetPlatform.android
//         ? settings.androidDevices[settings.initialDeviceIndex]
//         : settings.iosDevices[settings.initialDeviceIndex];
//     _currentOrientation = settings.orientation;
//     _brightness = settings.brightness;
//     _menuPosition = settings.menuPosition;
//   }

//   SimulatorSettings get settings => _settings;

//   Brightness get brightness => _brightness;

//   DeviceDescriptor get currentDevice => _currentDecvice;

//   Orientation get orientation => _currentOrientation;

//   MediaQueryData get realMediaQuery => _realMediaQuery;

//   Size get simulatedSize => _settings.androidDevices[0].size;

//   Color get accentColor => Colors.red;

//   Color get dividerColor => Colors.red;

//   bool get showColorSelector => true;

//   MenuPosition get menuPosition => _menuPosition;

//   TargetPlatform get currentPlatform => _currentDecvice.platform;

//   void onBrightnessChanged(Brightness value) {
//     _brightness = value;
//     notifyListeners();
//   }

//   void onColorChanged(ColorDescriptor? color) {}

//   void onDeviceChanged(DeviceChanged device) {
//     _currentDecvice = device.device;
//     _currentOrientation = device.orientation;
//     notifyListeners();
//   }

//   void setRealMediaQuery(MediaQueryData data) {
//     _realMediaQuery = data;
//   }

//   void onLogoClick() {
//     var next = _menuPosition.index + 1;
//     if (next >= MenuPosition.values.length) {
//       next = 0;
//     }
//     _menuPosition = MenuPosition.values[next];
//     notifyListeners();
//     // _realMediaQuery = data;
//   }
// }

==> dotup_flutter_simulator-3.0.1.tar.gz: lib/src/simulator/simulator_controller.dart <==
import 'package:dotup_flutter_widgets/dotup_flutter_widgets.dart';
import 'package:flutter/material.dart';

import '../device/device_changed.dart';
import '../device/device_descriptor.dart';
import '../settings/menu_position.dart';
import '../settings/simulator_settings.dart';

class SimulatorController extends ChangeNotifier {
  late final SimulatorSettings _settings;
  late MediaQueryData _realMediaQuery;
  late DeviceDescriptor _currentDecvice;
  late Orientation _currentOrientation;
  late Brightness _brightness;
  late MenuPosition _menuPosition;
  late bool _showMenuBar;

  SimulatorController(SimulatorSettings settings) {
    _settings = settings;
    _currentDecvice = settings.initialPlatform == TargetPlatform.android
        ? settings.androidDevices[settings.initialDeviceIndex]
        : settings.iosDevices[settings.initialDeviceIndex];
    _currentOrientation = settings.orientation;
    _brightness = settings.brightness;
    _menuPosition = settings.menuPosition;
    _showMenuBar = settings.showBottomBar;
  }

  SimulatorSettings get settings => _settings;

  Brightness get brightness => _brightness;

  DeviceDescriptor get currentDevice => _currentDecvice;

  Orientation get orientation => _currentOrientation;

  MediaQueryData get realMediaQuery => _realMediaQuery;

  Size get simulatedSize => _currentDecvice.size;

  Color get accentColor => _settings.accentColor;

  Color get dividerColor => _settings.dividerColor;

  bool get showColorSelector => _settings.showColorSelector;

  bool get showMenuBar => _showMenuBar;

  MenuPosition get menuPosition => _menuPosition;

  TargetPlatform get currentPlatform => _currentDecvice.platform;

  Widget? _overlayWidget;
  Widget? get overlayWidget => _overlayWidget;

  void onBrightnessChanged(Brightness value) {
    _brightness = value;
    notifyListeners();
  }

  void onColorChanged(ColorDescriptor? color) {}

  void onDeviceChanged(DeviceChanged device) {
    _currentDecvice = device.device;
    _currentOrientation = device.orientation;
    notifyListeners();
  }

  void setRealMediaQuery(MediaQueryData data) {
    _realMediaQuery = data;
  }

  void onLogoClick() {
    var next = _menuPosition.index + 1;
    if (next >= MenuPosition.values.length) {
      next = 0;
    }
    _menuPosition = MenuPosition.values[next];
    notifyListeners();
    // _realMediaQuery = data;
  }

  void toggleMenu() {
    _showMenuBar = !_showMenuBar;
    notifyListeners();
  }

  void setOverlayWidget(Widget? widget) {
    _overlayWidget = widget;
    notifyListeners();
  }
}

// import 'package:dotup_flutter_widgets/dotup_flutter_widgets.dart';
// import 'package:flutter/material.dart';

// import '../device/device_changed.dart';
// import '../device/device_descriptor.dart';
// import '../settings/menu_position.dart';
// import '../settings/simulator_settings.dart';

// class SimulatorController extends ChangeNotifier {
//   late final SimulatorSettings _settings;
//   late MediaQueryData _realMediaQuery;
//   late DeviceDescriptor _currentDecvice;
//   late Orientation _currentOrientation;
//   late Brightness _brightness;
//   late MenuPosition _menuPosition;

//   SimulatorController(SimulatorSettings settings) {
//     _settings = settings;
//     _currentDecvice = settings.initialPlatform == TargetPlatform.android
//         ? settings.androidDevices[settings.initialDeviceIndex]
//         : settings.iosDevices[settings.initialDeviceIndex];
//     _currentOrientation = settings.orientation;
//     _brightness = settings.brightness;
//     _menuPosition = settings.menuPosition;
//   }

//   SimulatorSettings get settings => _settings;

//   Brightness get brightness => _brightness;

//   DeviceDescriptor get currentDevice => _currentDecvice;

//   Orientation get orientation => _currentOrientation;

//   MediaQueryData get realMediaQuery => _realMediaQuery;

//   Size get simulatedSize => _settings.androidDevices[0].size;

//   Color get accentColor => Colors.red;

//   Color get dividerColor => Colors.red;

//   bool get showColorSelector => true;

//   MenuPosition get menuPosition => _menuPosition;

//   TargetPlatform get currentPlatform => _currentDecvice.platform;

//   void onBrightnessChanged(Brightness value) {
//     _brightness = value;
//     notifyListeners();
//   }

//   void onColorChanged(ColorDescriptor? color) {}

//   void onDeviceChanged(DeviceChanged device) {
//     _currentDecvice = device.device;
//     _currentOrientation = device.orientation;
//     notifyListeners();
//   }

//   void setRealMediaQuery(MediaQueryData data) {
//     _realMediaQuery = data;
//   }

//   void onLogoClick() {
//     var next = _menuPosition.index + 1;
//     if (next >= MenuPosition.values.length) {
//       next = 0;
//     }
//     _menuPosition = MenuPosition.values[next];
//     notifyListeners();
//     // _realMediaQuery = data;
//   }
// }
